from .core import git_commit

def main():
    """
    Função principal que chama a função git_commit, para realizar o commit.
    """
    
    git_commit()
    
    